@@ -1,4 +1,5 @@
 """pytest for bpa."""
+
 import pytest
 import pytabular as p
 from test.config import testing_parameters
@@ -8,8 +9,8 @@ from os import getcwd
 @pytest.mark.parametrize("model", testing_parameters)
 def test_bpa(model):
     """Testing execution of `model.analyze_bpa()`."""
-    te2 = p.TabularEditor().exe
-    bpa = p.BPA().location
+    te2 = p.TabularEditor(verify_download=False).exe
+    bpa = p.BPA(verify_download=False).location
     assert isinstance(model.analyze_bpa(te2, bpa), list)
 
 
